<?php
require 'db_connection.php';

// Fetch the current date and time
$current_date = date('F j, Y');
$current_time = date('h:i:s A');

// Fetch the staff data for the current month
$sql = "SELECT staff.id, staff.full_name, staff.profile_picture, 
               SUM(staff_activities.exports_quantity) AS total_exports, 
               AVG(staff_activities.on_time) * 100 AS average_on_time, 
               AVG(staff_activities.cleaning) * 100 AS average_cleaning, 
               AVG(staff_activities.manager_score) AS average_manager_score,
               (AVG(staff_activities.on_time) + AVG(staff_activities.cleaning) + AVG(staff_activities.manager_score)) / 3 AS total_score_month
        FROM staff
        LEFT JOIN staff_activities ON staff.id = staff_activities.staff_id
        WHERE MONTH(staff_activities.activity_date) = ?
        GROUP BY staff.id
        ORDER BY total_score_month DESC";
$stmt = $conn->prepare($sql);
$current_month = date('n');
$stmt->bind_param('i', $current_month);
$stmt->execute();
$result = $stmt->get_result();

// Construct the response array
$response = [
    'current_date' => $current_date,
    'current_time' => $current_time,
    'staff_data' => [],
];

while ($row = $result->fetch_assoc()) {
    $staff = [
        'id' => $row['id'],
        'full_name' => $row['full_name'],
        'profile_picture' => $row['profile_picture'],
        'total_exports' => $row['total_exports'],
        'average_on_time' => $row['average_on_time'],
        'average_cleaning' => $row['average_cleaning'],
        'average_manager_score' => $row['average_manager_score'],
        'total_score_month' => round($row['total_score_month'] * 100, 2),
    ];

    $response['staff_data'][] = $staff;
}

// Return the response as JSON
header('Content-Type: application/json');
echo json_encode($response);
