<!DOCTYPE html>
<html>
<head>
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <title>Staff Performance Dashboard</title>
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/4.7.0/css/font-awesome.min.css">
    <link rel="stylesheet" href="https://maxcdn.bootstrapcdn.com/bootstrap/4.5.2/css/bootstrap.min.css">
    <script src="https://ajax.googleapis.com/ajax/libs/jquery/3.5.1/jquery.min.js"></script>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/popper.js/1.16.0/umd/popper.min.js"></script>
    <script src="https://maxcdn.bootstrapcdn.com/bootstrap/4.5.2/js/bootstrap.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/chart.js"></script>
    <style>
        body {
            font-family: Arial, Helvetica, sans-serif;
            margin: 0;
            padding: 0;
        }
        .header {
            background-color: #2f4050;
            color: #ffffff;
            padding: 20px;
            text-align: center;
        }
        .row {
            display: flex;
            flex-wrap: wrap;
            justify-content: center;
        }
        .card {
            margin: 20px;
            padding: 20px;
            text-align: center;
            border: 1px solid #ccc;
            border-radius: 10px;
            box-shadow: 0 4px 8px 0 rgba(0, 0, 0, 0.2);
            max-width: 300px;
        }
        .card img {
            border-radius: 50%;
            margin-bottom: 10px;
            max-width: 150px;
            max-height: 150px;
        }
        .card h4 {
            margin-bottom: 10px;
        }
        .chart-container {
            margin-top: 20px;
        }
    </style>
</head>
<body>

    <!-- Header -->
    <div class="header">
        <h1>Staff Performance Dashboard</h1>
        <p id="current-time"></p>
    </div>

<!-- Main Content -->
<div class="container">
  <div class="row justify-content-center">
    <div class="col-md-8">

      <div class="card">
        <div class="card-header">Staff Activity Summary</div>

        <div class="card-body">
          <div class="row">
            <div class="col-4">
              <h4 id="current-date"></h4>
            </div>
            <div class="col-8">
              <div id="chart"></div>
            </div>
          </div>

          <br>

          <div class="row">
            <?php while ($row = $summary_data->fetch_assoc()): ?>
              <div class="col-md-3 mb-3">
                <div class="card">
                  <img src="<?php echo $row['profile_picture']; ?>" class="card-img-top mx-auto" alt="Profile Picture" style="width: 100px; height: 100px; object-fit: cover; border-radius: 50%;">
                  <div class="card-body text-center">
                    <h5 class="card-title"><?php echo $row['full_name']; ?></h5>
                    <p class="card-text">Total Score: <?php echo round($row['total_score_month'] * 100, 2); ?>%</p>
                  </div>
                </div>
              </div>
            <?php endwhile; ?>
          </div>
        </div>
      </div>

    </div>
  </div>
</div>

<script>
  // Get the current date
  const currentDate = new Date();
  const options = { weekday: 'long', year: 'numeric', month: 'long', day: 'numeric' };
  document.getElementById("current-date").innerHTML = currentDate.toLocaleDateString('en-US', options);

  // Generate the chart
  var chart = new ProgressBar.Circle('#chart', {
    strokeWidth: 6,
    easing: 'easeInOut',
    duration: 1400,
    color: '#1abc9c',
    trailColor: '#f4f4f4',
    trailWidth: 6,
    svgStyle: null
  });

  // Animate the chart with the total average score
  chart.animate(<?php echo $total_average_score_month; ?>); // Total average score for the month
</script>

<script>
  $(document).ready(function () {
    function fetchStaffData() {
      $.ajax({
        url: "get_staff_data.php",
        type: "POST",
        dataType: "json",
        success: function (response) {
          $("#current-date").text(response.current_date);
          $("#current-time").text(response.staff.current_time);

          $.each(response.staff_data, function (index, staff) {
            var $staffCard = $("<div>", {
              class: "col-lg-3 col-md-6 mb-4",
            }).append(
              $("<div>", {
                class: "card h-100",
              }).append(
                $("<img>", {
                  class: "card-img-top",
                  src: staff.profile_picture,
                  alt: "Profile Picture",
                }),
                $("<div>", {
                  class: "card-body",
                }).append(
                  $("<h4>", {
                    class: "card-title",
                    text: staff.full_name,
                  }),
                  $("<div>", {
                    class: "progress",
                  }).append(
                    $("<div>", {
                      class: "progress-bar",
                      role: "progressbar",
                      "aria-valuenow": staff.total_score_month,
                      "aria-valuemin": 0,
                      "aria-valuemax": 100,
                      style: `width: ${staff.total_score_month}%`,
                      text: `${staff.total_score_month.toFixed(2)}%`,
                    })
                  )
                )
              )
            );
            $("#staff_cards").append($staffCard);
          });
        },
        error: function (jqXHR, textStatus, errorThrown) {
          console.log(textStatus, errorThrown);
        },
      });
    }

    setInterval(fetchStaffData, 30000);
  });
</script>


