<?php
session_start();

if (!isset($_SESSION['user_id'])) {
    header("Location: login.php");
    exit;
}

require 'db_connection.php';

$sql = "SELECT * FROM staff";
$result = $conn->query($sql);

// Fetch and calculate the summary data for each staff member
function fetch_summary_data($conn, $month) {
    $sql = "SELECT staff.id, staff.full_name, staff.profile_picture, COUNT(staff_activities.id) AS total_active_days, SUM(staff_activities.exports_quantity) AS total_exports, 
                   AVG(staff_activities.on_time) * 100 AS average_on_time, AVG(staff_activities.cleaning) * 100 AS average_cleaning, AVG(staff_activities.manager_score) AS average_manager_score
            FROM staff
            LEFT JOIN staff_activities ON staff.id = staff_activities.staff_id
            WHERE MONTH(staff_activities.activity_date) = ?
            GROUP BY staff.id
            ORDER BY total_exports DESC";
    $stmt = $conn->prepare($sql);
    $stmt->bind_param("i", $month);
    $stmt->execute();
    $result = $stmt->get_result();
    return $result;
}

$selected_month = isset($_POST['month']) ? $_POST['month'] : date("n");
$summary_data = fetch_summary_data($conn, $selected_month);
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Staff Management</title>
    <link rel="stylesheet" href="https://maxcdn.bootstrapcdn.com/bootstrap/4.5.2/css/bootstrap.min.css">
    <script src="https://ajax.googleapis.com/ajax/libs/jquery/3.5.1/jquery.min.js"></script>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/popper.js/1.16.0/umd/popper.min.js"></script>
    <script src="https://maxcdn.bootstrapcdn.com/bootstrap/4.5.2/js/bootstrap.min.js"></script>
</head>
<body>
    <?php
session_start();
if (isset($_SESSION['message'])) {
    echo "<div class='alert alert-info'>" . $_SESSION['message'] . "</div>";
    unset($_SESSION['message']);
}
?>
    <div class="container">
        <h2 class="my-4">Staff List</h2>
        <table class="table table-bordered">
            <thead>
                <tr>
                    <th>ID</th>
                    <th>Full Name</th>
                    <th>Role</th>
                    <th>Action</th>
                </tr>
            </thead>
            <tbody>
                <?php while ($row = $result->fetch_assoc()): ?>
                    <tr>
                        <td><?php echo $row['id']; ?></td>
                        <td><?php echo $row['full_name']; ?></td>
                        <td><?php echo $row['role']; ?></td>
                        <td>
                            <button class="btn btn-primary add-activity" data-id="<?php echo $row['id']; ?>">Add Activity</button>
                        </td>
                    </tr>
                <?php endwhile; ?>
            </tbody>
        </table>
    </div>

    <!-- Add Activity Modal -->
    <div class="modal" tabindex="-1" id="addActivityModal">
        <div class="modal-dialog">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title">Add Daily Activity</h5>
                    <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                        <span aria-hidden="true">&times;</span>
                    </button>
                </div>
                <div class="modal-body">
                    <form id="addActivityForm" action="add_activity.php" method="post" enctype="multipart/form-data">
                                               <input type="hidden" name="staff_id" id="staffId">
                        <div class="form-group">
                            <label for="activity_date">Date</label>
                            <input type="date" class="form-control" id="activity_date" name="activity_date" required>
                        </div>
                        <div class="form-group">
                            <label for="exports_quantity">Quantity of Exports</label>
                            <input type="number" class="form-control" id="exports_quantity" name="exports_quantity" required>
                        </div>
                        <div class="form-group">
                            <label for="on_time">On Time</label>
                            <select class="form-control" id="on_time" name="on_time" required>
                                <option value="1">Yes</option>
                                <option value="0">No</option>
                            </select>
                        </div>
                        <div class="form-group">
                            <label for="cleaning">Cleaning</label>
                            <select class="form-control" id="cleaning" name="cleaning" required>
                                <option value="1">Done</option>
                                <option value="0">Not Done</option>
                            </select>
                        </div>
                        <div class="form-group">
                            <label for="manager_score">Manager Score</label>
                            <input type="number" class="form-control" id="manager_score" name="manager_score" required>
                        </div>
                        <button type="submit" class="btn btn-primary">Add Activity</button>
                    </form>
                </div>
            </div>
        </div>
    </div>
<!-- Staff Activity Summary -->
<div class="container">
<h2 class="my-4">Staff Activity Summary</h2>
<form id="selectMonthForm" method="post">
    <div class="form-group">
        <label for="month">Select Month:</label>
        <select class="form-control" id="month" name="month" onchange="this.form.submit()">
            <?php for ($i = 1; $i <= 12; $i++): ?>
                <option value="<?php echo $i; ?>" <?php echo ($i == $selected_month) ? 'selected' : ''; ?>><?php echo date("F", mktime(0, 0, 0, $i, 10)); ?></option>
            <?php endfor; ?>
        </select>
    </div>
</form>
<table class="table table-bordered">
    <thead>
        <tr>
            <th>Profile Picture</th>
            <th>Full Name</th>
            <th>Total Active Days</th>
            <th>Total Exports</th>
            <th>Average On Time (%)</th>
            <th>Average Cleaning (%)</th>
            <th>Average Manager Score</th>
            <th>Total Score Month</th>
        </tr>
    </thead>
    <tbody>
        <?php while ($row = $summary_data->fetch_assoc()): ?>
            <tr>
                <td><img src="<?php echo $row['profile_picture']; ?>" alt="Profile Picture" width="50" height="50"></td>
                <td><?php echo $row['full_name']; ?></td>
                <td><?php echo $row['total_active_days']; ?></td>
                <td><?php echo $row['total_exports']; ?></td>
                <td><?php echo round($row['average_on_time'], 2); ?></td>
                <td><?php echo round($row['average_cleaning'], 2); ?></td>
                <td><?php echo round($row['average_manager_score'], 2); ?></td>
                <td>
    <?php
    // Calculate the staff score based on the provided conditions
    $total_score_month = 0;
    $active_days_percentage = ($row['total_active_days'] / 24) * 0.4;
    $exports_percentage = ($row['total_exports'] / 72) * 0.4;
    $on_time_percentage = ($row['average_on_time'] / 100) * 0.05;
    $cleaning_percentage = ($row['average_cleaning'] / 100) * 0.05;
    $manager_score_percentage = ($row['average_manager_score'] / 9) * 0.1;

    $total_score_month = $active_days_percentage + $exports_percentage + $on_time_percentage + $cleaning_percentage + $manager_score_percentage;
    echo round($total_score_month * 100, 2);
    ?>
</td>

            </tr>
        <?php endwhile; ?>
    </tbody>
</table>

</div>
    <script>
$(document).ready(function () {
    $(".add-activity").click(function () {
        const staffId = $(this).data("id");
        $("#staffId").val(staffId);
        $("#addActivityModal").modal("show");
    });
});

    </script>
</body>
</html>
