<?php
require_once 'functions.php';

// Handle form submission
if ($_SERVER["REQUEST_METHOD"] == "POST") {
  $productName = $_POST['product_name'];
  $productDescription = $_POST['product_description'];
  $productCategory = $_POST['product_category'];
  addProduct($productName, $productDescription, $productCategory);
}

// Get products from the database
$products = getProducts();
?>

<!DOCTYPE html>
<html lang="en">
<head>
  <meta charset="UTF-8">
  <title>Products Management</title>
  <link rel="stylesheet" href="https://maxcdn.bootstrapcdn.com/bootstrap/4.5.2/css/bootstrap.min.css">
  <script src="https://ajax.googleapis.com/ajax/libs/jquery/3.5.1/jquery.min.js"></script>
  <script src="https://cdnjs.cloudflare.com/ajax/libs/popper.js/1.16.0/umd/popper.min.js"></script>
  <script src="https://maxcdn.bootstrapcdn.com/bootstrap/4.5.2/js/bootstrap.min.js"></script>
  <link rel="stylesheet" href="styles.css">
</head>
<body>
  <h1 class="text-center mb-4">Products Management</h1>

  <div class="container">
    <form method="post" action="<?php echo htmlspecialchars($_SERVER["PHP_SELF"]); ?>">
      <div class="form-group">
        <label for="product_name">Name:</label>
        <input type="text" name="product_name" class="form-control" required>
      </div>
      <div class="form-group">
        <label for="product_description">Description:</label>
        <input type="text" name="product_description" class="form-control" required>
      </div>
      <div class="form-group">
        <label for="product_category">Category:</label>
        <input type="text" name="product_category" class="form-control" required>
      </div>
      <button type="submit" class="btn btn-primary">Add Product</button>
    </form>
  </div>

  <div class="container mt-4">
    <div class="table-responsive">
      <table class="table table-striped">
        <thead>
          <tr>
            <th>Name</th>
            <th>Description</th>
            <th>Category</th>
            <th>Status</th>
            <th>Date Added</th>
            <th>Date Delivered</th>
            <th>Action</th>
          </tr>
        </thead>
        <tbody>
<?php foreach ($products as $product): ?>
    <tr class="<?php echo $product['status']; ?>">
        <td><?php echo $product['product_name']; ?></td>
        <td><?php echo $product['product_description']; ?></td>
        <td><?php echo $product['product_category']; ?></td>
        <td><?php echo $product['status']; ?></td>
        <td><?php echo $product['date_added']; ?></td>
        <td><?php echo $product['date_delivered'] ? $product['date_delivered'] : ''; ?></td>
        <td>
            <?php if ($product['status'] === 'received'): ?>
                <a href="#" class="mark-delivered" data-id="<?php echo $product['id']; ?>">Mark as Delivered</a>
 |
            <?php endif; ?>
            <a href="#" class="delete-product" data-id="<?php echo $product['id']; ?>">Delete</a>


        </td>
    </tr>
<?php endforeach; ?>



        </tbody>
      </table>
    </div>
  </div>

<script>
  $(document).ready(function () {
    // Mark as delivered
    $('.mark-delivered').on('click', function (e) {
      e.preventDefault();

      var id = $(this).data('id');
      var url = 'update_status.php?id=' + id;

      window.location.href = url;
    });

    // Delete product
    $('.delete-product').on('click', function (e) {
      e.preventDefault();

      if (confirm('Are you sure you want to delete this product?')) {
        var id = $(this).data('id');
        var url = 'delete_product.php?id=' + id;

        window.location.href = url;
      }
    });
  });
</script>


</body>

</html>
